@@ -1,4 +1,4 @@
-% Copyright (c) 2002, 2015 Jens Keiner, Stefan Kunis, Daniel Potts
+% Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
 %
 % This program is free software; you can redistribute it and/or modify it under
 % the terms of the GNU General Public License as published by the Free Software
@@ -13,8 +13,6 @@
 % You should have received a copy of the GNU General Public License along with
 % this program; if not, write to the Free Software Foundation, Inc., 51
 % Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-%
-% $Id$
 function [f,f_direct]=fastsum(x,alpha,y,kernel,c,m,n,p,eps_I,eps_B)
 
 % f=fastsum(x,alpha,y,kernel,c,m,n,p)
@@ -29,11 +27,26 @@ function [f,f_direct]=fastsum(x,alpha,y,kernel,c,m,n,p,eps_I,eps_B)
 %   size(x) = [N,d]
 %   size(alpha) = [N,1] (complex)
 %   size(y)=[M,d]
-%   kernel = 'multiquadric', e.g.
+%   kernel = 'multiquadric', etc. (see options below)
 %   c kernel parameter
 %   m cut-off parameter for NFFT
 %   n expansion degree
 %   p smoothness
+% 
+%   Kernel functions:
+%   'gaussian'                K(x) = EXP(-x^2/c^2) 
+%   'multiquadric'            K(x) = SQRT(x^2+c^2)
+%   'inverse_multiquadric'    K(x) = 1/SQRT(x^2+c^2)
+%   'logarithm'               K(x) = LOG |x|
+%   'thinplate_spline'        K(x) = x^2 LOG |x|
+%   'one_over_square'         K(x) = 1/x^2
+%   'one_over_modulus'        K(x) = 1/|x|
+%   'one_over_x'              K(x) = 1/x
+%   'inverse_multiquadric3'   K(x) = 1/SQRT(x^2+c^2)^3
+%   'sinc_kernel'             K(x) = SIN(cx)/x
+%   'cosc'                    K(x) = COS(cx)/x
+%   'cot'                     K(x) = cot(cx)
+%   'one_over_cube'           K(x) = 1/x^3
 %
 % Markus Fenn, 2006.
 
@@ -47,7 +60,12 @@ save -ascii -double alpha.dat alpha2
 save -ascii -double y.dat y
 
 %execute C-program for fast summation
-system(sprintf('./fastsum_matlab %d %d %d %d %d %d %s %e %e %e',d,N,M,n,m,p,kernel,c,eps_I,eps_B));
+if ispc
+    cmd='fastsum_matlab.exe';
+else 
+    cmd='./fastsum_matlab';
+end
+system(sprintf('%s %d %d %d %d %d %d %s %e %e %e',cmd,d,N,M,n,m,p,kernel,c,eps_I,eps_B));
 
 %read result from file
 f2=load('f.dat');
