@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2015 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -16,8 +16,6 @@
  * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-/* $Id$ */
-
 /*! \file taylor_nfft.c
  *
  * \brief Testing the nfft againt a Taylor expansion based version.
@@ -236,7 +234,7 @@ static void taylor_time_accuracy(int N, int M, int n, int m, int n_taylor,
     printf("%.2" __FES__ "\t", t_ndft);
   }
   else
-    printf("N/A\t\t");
+    printf("NaN\t");
 
   /* NFFT */
   t_nfft = K(0.0);
@@ -257,7 +255,7 @@ static void taylor_time_accuracy(int N, int M, int n, int m, int n_taylor,
   if (test_accuracy)
     printf("%.2" __FES__ "\t", NFFT(error_l_infty_complex)(swapndft, np.f, np.M_total));
   else
-    printf("N/A\t\t");
+    printf("NaN\t");
 
   /** TAYLOR NFFT */
   t_taylor = K(0.0);
@@ -278,7 +276,7 @@ static void taylor_time_accuracy(int N, int M, int n, int m, int n_taylor,
   if (test_accuracy)
     printf("%.2" __FES__ "\n", NFFT(error_l_infty_complex)(swapndft, np.f, np.M_total));
   else
-    printf("N/A\t\n");
+    printf("NaN\n");
 
   fflush(stdout);
 
