@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2015 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,16 @@
 
 #define NREPEAT 5
 
+#if defined(_WIN32) || defined(_WIN64)
+const char *CMD_CREATEDATASET = "nfsft_benchomp_createdataset.exe";
+const char *CMD_DETAIL_SINGLE = "nfsft_benchomp_detail_single.exe";
+const char *CMD_DETAIL_THREADS = "nfsft_benchomp_detail_threads.exe";
+#else
+const char *CMD_CREATEDATASET = "./nfsft_benchomp_createdataset";
+const char *CMD_DETAIL_SINGLE = "./nfsft_benchomp_detail_single";
+const char *CMD_DETAIL_THREADS = "./nfsft_benchomp_detail_threads";
+#endif
+
 static FILE* file_out_tex = NULL;
 
 int get_nthreads_array(int **arr)
@@ -86,7 +96,7 @@ void run_test_create(int trafo_adjoint, int N, int M)
 {
   char cmd[1025];
 
-  snprintf(cmd, 1024, "./nfsft_benchomp_createdataset %d %d %d > nfsft_benchomp_test.data", trafo_adjoint, N, M);
+  snprintf(cmd, 1024, "%s %d %d %d > nfsft_benchomp_test.data", CMD_CREATEDATASET, trafo_adjoint, N, M);
   fprintf(stderr, "%s\n", cmd);
   check_result_value(system(cmd), 0, "createdataset");
 }
@@ -140,9 +150,9 @@ void run_test(s_resval *res, int nrepeat, int m, int nfsft_flags, int psi_flags,
   }
 
   if (nthreads < 2)
-    snprintf(cmd, 1024, "./nfsft_benchomp_detail_single %d %d %d %d < nfsft_benchomp_test.data > nfsft_benchomp_test.out", m, nfsft_flags, psi_flags, nrepeat);
+    snprintf(cmd, 1024, "%s %d %d %d %d < nfsft_benchomp_test.data > nfsft_benchomp_test.out", CMD_DETAIL_SINGLE, m, nfsft_flags, psi_flags, nrepeat);
   else
-    snprintf(cmd, 1024, "./nfsft_benchomp_detail_threads %d %d %d %d %d < nfsft_benchomp_test.data > nfsft_benchomp_test.out", m, nfsft_flags, psi_flags, nrepeat, nthreads);
+    snprintf(cmd, 1024, "%s %d %d %d %d %d < nfsft_benchomp_test.data > nfsft_benchomp_test.out", CMD_DETAIL_THREADS, m, nfsft_flags, psi_flags, nrepeat, nthreads);
   fprintf(stderr, "%s\n", cmd);
 
   check_result_value(system(cmd), 0, cmd);
@@ -319,7 +329,9 @@ void print_output_speedup_total_tref(FILE *out, s_testset *testsets, int ntestse
   char plottitle[1025];
   unsigned int diff_mask = determine_different_parameters(testsets, ntestsets);
 
+#ifdef HAVE_GETHOSTNAME
   if (gethostname(hostname, 1024) != 0)
+#endif
     strncpy(hostname, "unnamed", 1024);
 
   get_plot_title(plottitle, 1024, hostname, testsets[0].param, diff_mask);
@@ -388,7 +400,9 @@ void print_output_histo_PENRT(FILE *out, s_testset testset)
   int i, size = testset.nresults;
   char hostname[1025];
 
+#ifdef HAVE_GETHOSTNAME
   if (gethostname(hostname, 1024) != 0)
+#endif
     strncpy(hostname, "unnamed", 1024);
 
   fprintf(out, "\\begin{tikzpicture}\n");
