@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2015 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -16,8 +16,6 @@
  * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-/* $Id$ */
-
 /**
  * \file fpt.c
  * \brief Implementation file for the FPT module
@@ -1047,7 +1045,7 @@ void fpt_precompute(fpt_set set, const int m, double *alpha, double *beta,
         {
           /* Stabilize. */
           degree_stab = degree*(2*l+1);
-          X(next_power_of_2_exp)((l+1)*(1<<(tau+1)),&N_stab,&t_stab);
+          X(next_power_of_2_exp_int)((l+1)*(1<<(tau+1)),&N_stab,&t_stab);
 
           /* Old arrays are to small. */
           nfft_free(a11);
@@ -1179,7 +1177,7 @@ void fpt_trafo_direct(fpt_set set, const int m, const double _Complex *x, double
   
     //fprintf(stderr, "Executing dpt.\n");  
 
-  X(next_power_of_2_exp)(k_end+1,&Nk,&tk);
+  X(next_power_of_2_exp_int)(k_end+1,&Nk,&tk);
   norm = 2.0/(Nk<<1);
 
     //fprintf(stderr, "Norm = %e.\n", norm);  
@@ -1277,7 +1275,7 @@ void fpt_trafo(fpt_set set, const int m, const double _Complex *x, double _Compl
     return;
   }
 
-  X(next_power_of_2_exp)(k_end,&Nk,&tk);
+  X(next_power_of_2_exp_int)(k_end,&Nk,&tk);
   k_start_tilde = K_START_TILDE(data->k_start,Nk);
   k_end_tilde = K_END_TILDE(k_end,Nk);
 
@@ -1522,7 +1520,7 @@ void fpt_transposed_direct(fpt_set set, const int m, double _Complex *x,
   int tk;
   double norm;
 
-  X(next_power_of_2_exp)(k_end+1,&Nk,&tk);
+  X(next_power_of_2_exp_int)(k_end+1,&Nk,&tk);
   norm = 2.0/(Nk<<1);
 
   if (set->flags & FPT_NO_DIRECT_ALGORITHM)
@@ -1609,7 +1607,7 @@ void fpt_transposed(fpt_set set, const int m, double _Complex *x,
     return;
   }
 
-  X(next_power_of_2_exp)(k_end,&Nk,&tk);
+  X(next_power_of_2_exp_int)(k_end,&Nk,&tk);
   k_start_tilde = K_START_TILDE(data->k_start,Nk);
   k_end_tilde = K_END_TILDE(k_end,Nk);
 
