@@ -29,7 +29,7 @@
 #include "cycle.h"
 #include "nfft.h"
 
-#define ABSPATH(x) ABS_SRCDIR SEP "tests" SEP x
+#define ABSPATH(x) ABS_SRCDIR "/tests/" x
 
 /* Testcase delegate. */
 typedef struct testcase_delegate_s testcase_delegate_t;
@@ -190,7 +190,7 @@ static R trafo_direct_cost(X(plan) *p)
             x += 1;
           }
           X(finalize)(&p2);
-          free(N);
+          Y(free)(N);
         }
       }
     }
@@ -211,7 +211,7 @@ static R trafo_direct_cost(X(plan) *p)
 static R err_trafo_direct(X(plan) *p)
 {
   UNUSED(p);
-  return K(40.0) * EPSILON;
+  return K(44.0) * EPSILON;
 }
 
 static R err_trafo(X(plan) *p)
@@ -381,11 +381,12 @@ static void setup_file(const testcase_delegate_t *ego_, int *d, int **N, int *NN
   const testcase_delegate_file_t *ego = (const testcase_delegate_file_t*)ego_;
   int j;
   char filename[200];
-  char* c = rindex(ego->filename, SEP[0]);
+  char* c = strrchr(ego->filename, '/');
   FILE *file = fopen(ego->filename, "r");
 
   filename[0] = (char) 0;
-  strcpy(filename, &c[1]);
+  strncpy(filename, &c[1], 200);
+  filename[199] = (char) 0;
   printf("%-31s", filename);
 
   /* Dimensions. */
@@ -449,9 +450,9 @@ static void setup_file(const testcase_delegate_t *ego_, int *d, int **N, int *NN
 static void destroy_file(const testcase_delegate_t *ego_, R *x, C *f_hat, C *f)
 {
   UNUSED(ego_);
-  free(x);
-  free(f_hat);
-  free(f);
+  Y(free)(x);
+  Y(free)(f_hat);
+  Y(free)(f);
 }
 
 static void setup_online(const testcase_delegate_t *ego_, int *d, int **N, int *NN, int *M, R **x, C **f_hat, C **f)
@@ -632,9 +633,9 @@ static void setup_adjoint_online(const testcase_delegate_t *ego_, int *d, int **
 static void destroy_online(const testcase_delegate_t *ego_, R *x, C *f_hat, C *f)
 {
   UNUSED(ego_);
-  free(x);
-  free(f_hat);
-  free(f);
+  Y(free)(x);
+  Y(free)(f_hat);
+  Y(free)(f);
 }
 
 /* Initializers. */
@@ -672,7 +673,7 @@ static void init_advanced_pre_psi_(init_delegate_t *ego, X(plan) *p, const int d
   for (i = 0; i < d; i++)
     n[i] = 2 * (int)(Y(next_power_of_2)(N[i]));
   X(init_guru)(p, d, N, M, n, ego->m, ego->flags, ego->fftw_flags);
-  free(n);
+  Y(free)(n);
 }
 
 //static void init_advanced_pre_lin_psi_(init_delegate_t *ego, X(plan) *p, const int d, const int *N, const int M)
@@ -684,7 +685,7 @@ static void init_advanced_pre_psi_(init_delegate_t *ego, X(plan) *p, const int d
 //  int K = ego->K  * (ego->m + 2);
 //  //printf("\n%d\n", K);
 //  X(init_lin)(p, d, N, M, n, ego->m, K, ego->flags, ego->fftw_flags);
-//  free(n);
+//  Y(free)(n);
 //}
 
 static init_delegate_t init_direct = {"init_guru ()", init_advanced_pre_psi_, WINDOW_HELP_ESTIMATE_m, (DEFAULT_NFFT_FLAGS ^ PRE_PSI), DEFAULT_FFTW_FLAGS};
